import React from "react";
import { BanIcon } from "@patternfly/react-icons/dist/js/icons/ban-icon";
import { CheckCircleIcon } from "@patternfly/react-icons/dist/js/icons/check-circle-icon";
import { ErrorCircleOIcon } from "@patternfly/react-icons/dist/js/icons/error-circle-o-icon";
import { InfoCircleIcon } from "@patternfly/react-icons/dist/js/icons/info-circle-icon";
import { OnRunningIcon } from "@patternfly/react-icons/dist/js/icons/on-running-icon";
import { Title, TitleSizes } from "@patternfly/react-core/dist/js/components/Title";
import { WorkflowInstanceState } from "@kie-tools/runtime-tools-gateway-api/dist/types";
import PausedIcon from "@patternfly/react-icons/dist/js/icons/paused-icon";
export const setTitle = (titleStatus, titleText) => {
    let icon = null;
    switch (titleStatus) {
        case "success":
            icon = React.createElement(InfoCircleIcon, { className: "pf-u-mr-sm", color: "var(--pf-global--info-color--100)" });
            break;
        case "failure":
            icon = React.createElement(InfoCircleIcon, { className: "pf-u-mr-sm", color: "var(--pf-global--danger-color--100)" });
            break;
    }
    return (React.createElement(Title, { headingLevel: "h1", size: TitleSizes["2xl"] },
        icon,
        React.createElement("span", null, titleText)));
};
export const constructObject = (obj, path, val) => {
    const keys = path.split(",");
    const lastKey = keys.pop();
    const lastObj = keys.reduce((_obj, key) => (_obj[key] = obj[key] || {}), obj);
    lastObj[lastKey] = val;
};
export const formatForBulkListJob = (jobsList) => {
    const formattedItems = [];
    jobsList.forEach((item) => {
        const formattedObj = {
            id: item.id,
            name: item.workflowId,
            description: item.id,
            errorMessage: item.errorMessage ? item.errorMessage : undefined,
        };
        formattedItems.push(formattedObj);
    });
    return formattedItems;
};
export const getWorkflowInstanceDescription = (workflowInstance) => {
    return {
        id: workflowInstance.id,
        name: workflowInstance.processName,
        description: workflowInstance.businessKey,
    };
};
export const WorkflowInstanceIconCreator = (state) => {
    switch (state) {
        case WorkflowInstanceState.Active:
            return (React.createElement(React.Fragment, null,
                React.createElement(OnRunningIcon, { className: "pf-u-mr-sm" }),
                "Active"));
        case WorkflowInstanceState.Completed:
            return (React.createElement(React.Fragment, null,
                React.createElement(CheckCircleIcon, { className: "pf-u-mr-sm", color: "var(--pf-global--success-color--100)" }),
                "Completed"));
        case WorkflowInstanceState.Aborted:
            return (React.createElement(React.Fragment, null,
                React.createElement(BanIcon, { className: "pf-u-mr-sm" }),
                "Aborted"));
        case WorkflowInstanceState.Suspended:
            return (React.createElement(React.Fragment, null,
                React.createElement(PausedIcon, { className: "pf-u-mr-sm" }),
                "Suspended"));
        case WorkflowInstanceState.Error:
            return (React.createElement(React.Fragment, null,
                React.createElement(ErrorCircleOIcon, { className: "pf-u-mr-sm", color: "var(--pf-global--danger-color--100)" }),
                "Error"));
    }
};
//# sourceMappingURL=Utils.js.map